
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#pragma once

#if !defined (__VTE_VTE_H_INSIDE__) && !defined (VTE_COMPILATION)
#error "Only <vte/vte.h> can be included directly."
#endif

#include <glib-object.h>

#include "vtemacros.h"

G_BEGIN_DECLS

/* enumerations from "vteenums.h" */
_VTE_PUBLIC
GType vte_cursor_blink_mode_get_type (void);
#define VTE_TYPE_CURSOR_BLINK_MODE (vte_cursor_blink_mode_get_type ())
_VTE_PUBLIC
GType vte_cursor_shape_get_type (void);
#define VTE_TYPE_CURSOR_SHAPE (vte_cursor_shape_get_type ())
_VTE_PUBLIC
GType vte_text_blink_mode_get_type (void);
#define VTE_TYPE_TEXT_BLINK_MODE (vte_text_blink_mode_get_type ())
_VTE_PUBLIC
GType vte_erase_binding_get_type (void);
#define VTE_TYPE_ERASE_BINDING (vte_erase_binding_get_type ())
_VTE_PUBLIC
GType vte_pty_error_get_type (void);
#define VTE_TYPE_PTY_ERROR (vte_pty_error_get_type ())
_VTE_PUBLIC
GType vte_pty_flags_get_type (void);
#define VTE_TYPE_PTY_FLAGS (vte_pty_flags_get_type ())
_VTE_PUBLIC
GType vte_write_flags_get_type (void);
#define VTE_TYPE_WRITE_FLAGS (vte_write_flags_get_type ())
_VTE_PUBLIC
GType vte_regex_error_get_type (void);
#define VTE_TYPE_REGEX_ERROR (vte_regex_error_get_type ())
_VTE_PUBLIC
GType vte_format_get_type (void);
#define VTE_TYPE_FORMAT (vte_format_get_type ())
_VTE_PUBLIC
GType vte_align_get_type (void);
#define VTE_TYPE_ALIGN (vte_align_get_type ())
_VTE_PUBLIC
GType vte_uuid_format_get_type (void);
#define VTE_TYPE_UUID_FORMAT (vte_uuid_format_get_type ())
_VTE_PUBLIC
GType vte_property_flags_get_type (void);
#define VTE_TYPE_PROPERTY_FLAGS (vte_property_flags_get_type ())
_VTE_PUBLIC
GType vte_property_type_get_type (void);
#define VTE_TYPE_PROPERTY_TYPE (vte_property_type_get_type ())
_VTE_PUBLIC
GType vte_property_id_get_type (void);
#define VTE_TYPE_PROPERTY_ID (vte_property_id_get_type ())
_VTE_PUBLIC
GType vte_progress_hint_get_type (void);
#define VTE_TYPE_PROGRESS_HINT (vte_progress_hint_get_type ())
G_END_DECLS

/* Generated data ends here */

